Create an image from a selected channel of another image (GRAYSCALE).
See also
Other from functions:
color_from_hsv(),
color_from_normalized(),
image_from_image()
Examples
if (FALSE) {
image_from_channel(gen_image_color(100, 100, "blue"), 0L)
}
Create an image from a selected channel of another image (GRAYSCALE).
Other from functions:
color_from_hsv(),
color_from_normalized(),
image_from_image()
if (FALSE) {
image_from_channel(gen_image_color(100, 100, "blue"), 0L)
}