Get the path to a file in the package's demo resources directory. Works correctly on both desktop and web (Emscripten virtual filesystem).
Get the path to a file in the package's demo resources directory. Works correctly on both desktop and web (Emscripten virtual filesystem).