Insert text in a defined byte position, memory must be MemFree().
See also
Other alloc functions:
text_replace_alloc(),
text_replace_between_alloc()
Other insert functions:
text_insert()
Insert text in a defined byte position, memory must be MemFree().
Other alloc functions:
text_replace_alloc(),
text_replace_between_alloc()
Other insert functions:
text_insert()